@@ -2,7 +2,7 @@ import os
 
 from .version import _warn_if_setuptools_outdated
 from .utils import do
-from .discover import find_matching_entrypoint
+from .discover import iter_matching_entrypoints
 from . import get_version
 
 
@@ -14,7 +14,10 @@ def version_keyword(dist, keyword, value):
         value = {}
     if getattr(value, '__call__', None):
         value = value()
-    if os.path.exists('PKG-INFO'):
+    # this piece of code is a hack to counter the mistake in root finding
+    matching_fallbacks = iter_matching_entrypoints(
+        '.', 'setuptools_scm.parse_scm_fallback')
+    if any(matching_fallbacks):
         value.pop('root', None)
     dist.metadata.version = get_version(**value)
 
@@ -23,7 +26,8 @@ def find_files(path='.'):
     if not path:
         path = '.'
     abs = os.path.abspath(path)
-    ep = find_matching_entrypoint(abs, 'setuptools_scm.files_command')
+    ep = next(iter_matching_entrypoints(
+        abs, 'setuptools_scm.files_command'), None)
     if ep:
         command = ep.load()
         try:
@@ -32,10 +36,8 @@ def find_files(path='.'):
             else:
                 return command(path)
         except Exception:
-            import traceback
             print("File Finder Failed for %s" % ep)
-            traceback.print_exc()
-            return []
+            raise
 
     else:
         return []
